Shivani Parekh has uploaded this change for review. ( https://gem5-review.googlesource.com/c/public/gem5/+/33641 )

Change subject: mem: Update addMaster() and hasMaster()
......................................................................

mem: Update addMaster() and hasMaster()

Change-Id: I24d78fa0394a45330a96f9811a5df6c7ce42423f
---
M src/mem/qos/mem_ctrl.cc
M src/mem/qos/mem_ctrl.hh
M src/mem/qos/q_policy.cc
3 files changed, 10 insertions(+), 10 deletions(-)



diff --git a/src/mem/qos/mem_ctrl.cc b/src/mem/qos/mem_ctrl.cc
index 21f5311..d7441b5 100644
--- a/src/mem/qos/mem_ctrl.cc
+++ b/src/mem/qos/mem_ctrl.cc
@@ -88,7 +88,7 @@
 {
     // If needed, initialize all counters and statistics
     // for this master
-    addMaster(m_id);
+    addRequestor(m_id);

     DPRINTF(QOS,
             "QoSMemCtrl::logRequest MASTER %s [id %d] address %d"
@@ -143,7 +143,7 @@
 MemCtrl::logResponse(BusState dir, MasterID m_id, uint8_t qos,
                      Addr addr, uint64_t entries, double delay)
 {
-    panic_if(!hasMaster(m_id),
+    panic_if(!hasRequestor(m_id),
         "Logging response with invalid master\n");

     DPRINTF(QOS,
@@ -266,14 +266,14 @@
 }

 void
-MemCtrl::addMaster(MasterID m_id)
+MemCtrl::addRequestor(MasterID m_id)
 {
-    if (!hasMaster(m_id)) {
+    if (!hasRequestor(m_id)) {
         masters.emplace(m_id, _system->getRequestorName(m_id));
         packetPriorities[m_id].resize(numPriorities(), 0);

         DPRINTF(QOS,
-                "QoSMemCtrl::addMaster registering"
+                "QoSMemCtrl::addRequestor registering"
                 " Master %s [id %d]\n",
                 masters[m_id], m_id);
     }
diff --git a/src/mem/qos/q_policy.cc b/src/mem/qos/q_policy.cc
index 5ebd063..6b99387 100644
--- a/src/mem/qos/q_policy.cc
+++ b/src/mem/qos/q_policy.cc
@@ -84,7 +84,7 @@
                      "from queue with id %d\n", m_id);

         // Check if this is a known master.
-        panic_if(memCtrl->hasMaster(m_id),
+        panic_if(memCtrl->hasRequestor(m_id),
                  "%s: Unrecognized Master\n", __func__);

         panic_if(toServe.size() > 0,

diff --git a/src/mem/qos/mem_ctrl.hh b/src/mem/qos/mem_ctrl.hh
index 1d82091..dee09b2 100644
--- a/src/mem/qos/mem_ctrl.hh
+++ b/src/mem/qos/mem_ctrl.hh
@@ -157,7 +157,7 @@
      *
      * @param m_id the master ID
      */
-    void addMaster(const MasterID m_id);
+    void addRequestor(const MasterID m_id);

     /**
      * Called upon receiving a request or
@@ -285,7 +285,7 @@
     BusState getBusStateNext() const { return busStateNext; }

     /**
      * hasMaster returns true if the selected master(ID) has
      * been registered in the memory controller, which happens if
      * the memory controller has received at least a packet from
      * that master.
@@ -294,7 +294,7 @@
      * @return true if the memory controller has received a packet
      *         from the master, false otherwise.
      */
-    bool hasMaster(MasterID m_id) const
+    bool hasRequestor(MasterID m_id) const
     {
         return masters.find(m_id) != masters.end();
     }
@@ -428,7 +428,7 @@
 {
     // If needed, initialize all counters and statistics
     // for this master
-    addMaster(m_id);
+    addRequestor(m_id);

     DPRINTF(QOS,
             "QoSMemCtrl::escalate Master %s [id %d] to priority "
@@ -285,7 +285,7 @@

     /**
-     * hasMaster returns true if the selected master(ID) has
+     * hasRequestor returns true if the selected master(ID) has
      * been registered in the memory controller, which happens if
      * the memory controller has received at least a packet from
--
To view, visit https://gem5-review.googlesource.com/c/public/gem5/+/33641
To unsubscribe, or for help writing mail filters, visit https://gem5-review.googlesource.com/settings

Gerrit-Project: public/gem5
Gerrit-Branch: develop
Gerrit-Change-Id: I24d78fa0394a45330a96f9811a5df6c7ce42423f
Gerrit-Change-Number: 33641
Gerrit-PatchSet: 1
Gerrit-Owner: Shivani Parekh <[email protected]>
Gerrit-MessageType: newchange
_______________________________________________
gem5-dev mailing list -- [email protected]
To unsubscribe send an email to [email protected]
%(web_page_url)slistinfo%(cgiext)s/%(_internal_name)s

Reply via email to